import { attachShadow, h, proxyCustomElement } from '@stencil/core/internal/client';
export { setAssetPath, setPlatformOptions } from '@stencil/core/internal/client';

function capitalize(string) {
  return string.charAt(0).toUpperCase() + string.slice(1);
}

const leanButtonCss = ".btn{background-color:var(--cl-main)}";

const LeanButton$1 = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    attachShadow(this);
  }
  render() {
    return h("button", { class: "btn" }, capitalize(this.label));
  }
  static get style() { return leanButtonCss; }
};

const leanHeaderCss = ".l-header{position:fixed;height:60px;width:100%;top:0;left:0;background-color:var(--cl-secondary)}";

const LeanHeader$1 = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    attachShadow(this);
  }
  render() {
    return (h("header", { class: "l-header" }, h("h1", null, this.label), this.loggedIn && h("lean-button", null, "Profile")));
  }
  static get style() { return leanHeaderCss; }
};

const leanListCss = ":host{display:block}";

const LeanList$1 = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    attachShadow(this);
  }
  render() {
    return (h("ul", null, h("h1", null, capitalize(this.label)), h("slot", null)));
  }
  static get style() { return leanListCss; }
};

const LeanButton = /*@__PURE__*/proxyCustomElement(LeanButton$1, [1,"lean-button",{"label":[1]}]);
const LeanHeader = /*@__PURE__*/proxyCustomElement(LeanHeader$1, [1,"lean-header",{"label":[1],"loggedIn":[4,"logged-in"]}]);
const LeanList = /*@__PURE__*/proxyCustomElement(LeanList$1, [1,"lean-list",{"label":[1]}]);
const defineCustomElements = (opts) => {
  if (typeof customElements !== 'undefined') {
    [
      LeanButton,
  LeanHeader,
  LeanList
    ].forEach(cmp => {
      if (!customElements.get(cmp.is)) {
        customElements.define(cmp.is, cmp, opts);
      }
    });
  }
};

export { LeanButton, LeanHeader, LeanList, defineCustomElements };
